package com.alterdekim.game.service;

import com.alterdekim.game.entity.Relationship;
import com.alterdekim.game.repository.RelationshipRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Optional;

@Service
public class RelationshipService {

    @Autowired
    private RelationshipRepository repository;

    public void save(Relationship relationship) {
        this.repository.save(relationship);
    }

    public Optional<Relationship> getById(Long id) {
        return this.repository.findById(id);
    }

    public Boolean isFriends(Long userId, Long userId1) {
        return this.repository.findRelation(userId, userId1, Relationship.FriendshipStatus.Friendship).isPresent();
    }

    public Optional<Relationship> isRequestSent(Long userId, Long userId1) {
        return this.repository.findRelation(userId, userId1, Relationship.FriendshipStatus.Request);
    }

    public void deleteRequest(Long id) {
        this.repository.deleteById(id);
    }

    public void acceptRequest(Long id) {
        this.repository.acceptRequestById(id);
    }

    public void sendRequest(Long sender, Long receiver) {
        if( this.isFriends(sender, receiver) ) return;
        if( this.isRequestSent(sender, receiver).isPresent() ) {
            Relationship r = this.isRequestSent(sender, receiver).get();
            if( r.getRecepientId().longValue() != sender.longValue() ) return;
            this.acceptRequest(r.getId());
            return;
        }
        this.repository.save(new Relationship(null, sender, receiver, Relationship.FriendshipStatus.Request));
    }
}
